PeerRole

Enum PeerRole 

#[non_exhaustive]
pub enum PeerRole { Publisher, Subscriber, Both, Other(String), }
Role a peer is acting in at connection time.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Publisher

Peer is acting as a publisher.



Subscriber

Peer is acting as a subscriber.



Both

Peer is acting as both.



Other(String)

A role this version of the crate does not know, kept verbatim.

Implementations

Source

impl PeerRole

pub fn as_str(&self) -> &str

The wire spelling of this role.

fn parse(s: &str) -> Self